# pymzxml a python library to read and write mzXML files

This package provides functions to read and write mzXML files.

Reading is achieved by wrapping the high performance RAMP C library from the [TransProteomicsPipeline](https://sourceforge.net/projects/sashimi/) project in python.

The library supports both single-shot and sequential writing of mzXML files.

For examples on how to use the function please refer to the [examples](https://github.com/digitalproteomes/pymzxml/tree/master/examples) at the GitHub repository.

## Installation

### From github
```pip install git+https://github.com/digitalproteomes/pymzxml.git```

### From pypi
```pip install pymzxml```
